@@ -21,7 +21,7 @@
 #ifndef ADDRESS_TEST_H
 #define ADDRESS_TEST_H
 
-#include <QtCore/QObject>
+#include <QObject>
 
 class AddressTest : public QObject
 {
@@ -42,6 +42,7 @@ private Q_SLOTS:
     void shouldParseAddressVCard4();
     void shouldExportVCard4WithGeoPosition();
     void shouldParseAddressVCard4WithGeoPosition();
+    void countryToISOTest();
 };
 
 #endif
